LINECONS - 48 Fully Scalable Vector Icons

# LINECONS

48 FULLY SCALABLE VECTOR ICONS

# CSS Class Names

li_heart li_cloud li_star li_tv li_sound li_video li_trash li_user li_key li_search li_settings li_camera li_tag li_lock li_bulb li_pen li_diamond li_display li_location li_eye li_bubble li_stack li_cup li_phone li_news li_mail li_like li_photo li_note li_clock li_paperplane li_params li_banknote li_data li_music li_megaphone li_study li_lab li_food li_t-shirt li_fire li_clip li_shop li_calendar li_vallet li_vynil li_truck li_world